@@ -15,7 +15,6 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Type, overload
 
-from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
 
 from mypy_boto3_connect.paginator import (
@@ -68,6 +67,14 @@ else:
 __all__ = ("ConnectClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
     ClientError: Type[BotocoreClientError]
     ContactNotFoundException: Type[BotocoreClientError]
@@ -85,7 +92,7 @@ class Exceptions:
 
 class ConnectClient:
     """
-    [Connect.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client)
+    [Connect.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client)
     """
 
     meta: ClientMeta
@@ -93,7 +100,7 @@ class ConnectClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.can_paginate)
         """
 
     def create_user(
@@ -110,31 +117,31 @@ class ConnectClient:
         Tags: Dict[str, str] = None,
     ) -> CreateUserResponseTypeDef:
         """
-        [Client.create_user documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.create_user)
+        [Client.create_user documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.create_user)
         """
 
     def delete_user(self, InstanceId: str, UserId: str) -> None:
         """
-        [Client.delete_user documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.delete_user)
+        [Client.delete_user documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.delete_user)
         """
 
     def describe_user(self, UserId: str, InstanceId: str) -> DescribeUserResponseTypeDef:
         """
-        [Client.describe_user documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.describe_user)
+        [Client.describe_user documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.describe_user)
         """
 
     def describe_user_hierarchy_group(
         self, HierarchyGroupId: str, InstanceId: str
     ) -> DescribeUserHierarchyGroupResponseTypeDef:
         """
-        [Client.describe_user_hierarchy_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.describe_user_hierarchy_group)
+        [Client.describe_user_hierarchy_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.describe_user_hierarchy_group)
         """
 
     def describe_user_hierarchy_structure(
         self, InstanceId: str
     ) -> DescribeUserHierarchyStructureResponseTypeDef:
         """
-        [Client.describe_user_hierarchy_structure documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.describe_user_hierarchy_structure)
+        [Client.describe_user_hierarchy_structure documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.describe_user_hierarchy_structure)
         """
 
     def generate_presigned_url(
@@ -145,14 +152,14 @@ class ConnectClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.generate_presigned_url)
         """
 
     def get_contact_attributes(
         self, InstanceId: str, InitialContactId: str
     ) -> GetContactAttributesResponseTypeDef:
         """
-        [Client.get_contact_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.get_contact_attributes)
+        [Client.get_contact_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.get_contact_attributes)
         """
 
     def get_current_metric_data(
@@ -165,12 +172,12 @@ class ConnectClient:
         MaxResults: int = None,
     ) -> GetCurrentMetricDataResponseTypeDef:
         """
-        [Client.get_current_metric_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.get_current_metric_data)
+        [Client.get_current_metric_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.get_current_metric_data)
         """
 
     def get_federation_token(self, InstanceId: str) -> GetFederationTokenResponseTypeDef:
         """
-        [Client.get_federation_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.get_federation_token)
+        [Client.get_federation_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.get_federation_token)
         """
 
     def get_metric_data(
@@ -185,7 +192,7 @@ class ConnectClient:
         MaxResults: int = None,
     ) -> GetMetricDataResponseTypeDef:
         """
-        [Client.get_metric_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.get_metric_data)
+        [Client.get_metric_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.get_metric_data)
         """
 
     def list_contact_flows(
@@ -208,14 +215,14 @@ class ConnectClient:
         MaxResults: int = None,
     ) -> ListContactFlowsResponseTypeDef:
         """
-        [Client.list_contact_flows documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.list_contact_flows)
+        [Client.list_contact_flows documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.list_contact_flows)
         """
 
     def list_hours_of_operations(
         self, InstanceId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListHoursOfOperationsResponseTypeDef:
         """
-        [Client.list_hours_of_operations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.list_hours_of_operations)
+        [Client.list_hours_of_operations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.list_hours_of_operations)
         """
 
     def list_phone_numbers(
@@ -467,7 +474,7 @@ class ConnectClient:
         MaxResults: int = None,
     ) -> ListPhoneNumbersResponseTypeDef:
         """
-        [Client.list_phone_numbers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.list_phone_numbers)
+        [Client.list_phone_numbers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.list_phone_numbers)
         """
 
     def list_queues(
@@ -478,47 +485,47 @@ class ConnectClient:
         MaxResults: int = None,
     ) -> ListQueuesResponseTypeDef:
         """
-        [Client.list_queues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.list_queues)
+        [Client.list_queues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.list_queues)
         """
 
     def list_routing_profiles(
         self, InstanceId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListRoutingProfilesResponseTypeDef:
         """
-        [Client.list_routing_profiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.list_routing_profiles)
+        [Client.list_routing_profiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.list_routing_profiles)
         """
 
     def list_security_profiles(
         self, InstanceId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListSecurityProfilesResponseTypeDef:
         """
-        [Client.list_security_profiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.list_security_profiles)
+        [Client.list_security_profiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.list_security_profiles)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.list_tags_for_resource)
         """
 
     def list_user_hierarchy_groups(
         self, InstanceId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListUserHierarchyGroupsResponseTypeDef:
         """
-        [Client.list_user_hierarchy_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.list_user_hierarchy_groups)
+        [Client.list_user_hierarchy_groups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.list_user_hierarchy_groups)
         """
 
     def list_users(
         self, InstanceId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListUsersResponseTypeDef:
         """
-        [Client.list_users documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.list_users)
+        [Client.list_users documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.list_users)
         """
 
     def resume_contact_recording(
         self, InstanceId: str, ContactId: str, InitialContactId: str
     ) -> Dict[str, Any]:
         """
-        [Client.resume_contact_recording documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.resume_contact_recording)
+        [Client.resume_contact_recording documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.resume_contact_recording)
         """
 
     def start_chat_contact(
@@ -531,7 +538,7 @@ class ConnectClient:
         ClientToken: str = None,
     ) -> StartChatContactResponseTypeDef:
         """
-        [Client.start_chat_contact documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.start_chat_contact)
+        [Client.start_chat_contact documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.start_chat_contact)
         """
 
     def start_contact_recording(
@@ -542,7 +549,7 @@ class ConnectClient:
         VoiceRecordingConfiguration: VoiceRecordingConfigurationTypeDef,
     ) -> Dict[str, Any]:
         """
-        [Client.start_contact_recording documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.start_contact_recording)
+        [Client.start_contact_recording documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.start_contact_recording)
         """
 
     def start_outbound_voice_contact(
@@ -556,84 +563,84 @@ class ConnectClient:
         Attributes: Dict[str, str] = None,
     ) -> StartOutboundVoiceContactResponseTypeDef:
         """
-        [Client.start_outbound_voice_contact documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.start_outbound_voice_contact)
+        [Client.start_outbound_voice_contact documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.start_outbound_voice_contact)
         """
 
     def stop_contact(self, ContactId: str, InstanceId: str) -> Dict[str, Any]:
         """
-        [Client.stop_contact documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.stop_contact)
+        [Client.stop_contact documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.stop_contact)
         """
 
     def stop_contact_recording(
         self, InstanceId: str, ContactId: str, InitialContactId: str
     ) -> Dict[str, Any]:
         """
-        [Client.stop_contact_recording documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.stop_contact_recording)
+        [Client.stop_contact_recording documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.stop_contact_recording)
         """
 
     def suspend_contact_recording(
         self, InstanceId: str, ContactId: str, InitialContactId: str
     ) -> Dict[str, Any]:
         """
-        [Client.suspend_contact_recording documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.suspend_contact_recording)
+        [Client.suspend_contact_recording documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.suspend_contact_recording)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.untag_resource)
         """
 
     def update_contact_attributes(
         self, InitialContactId: str, InstanceId: str, Attributes: Dict[str, str]
     ) -> Dict[str, Any]:
         """
-        [Client.update_contact_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.update_contact_attributes)
+        [Client.update_contact_attributes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.update_contact_attributes)
         """
 
     def update_user_hierarchy(
         self, UserId: str, InstanceId: str, HierarchyGroupId: str = None
     ) -> None:
         """
-        [Client.update_user_hierarchy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.update_user_hierarchy)
+        [Client.update_user_hierarchy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.update_user_hierarchy)
         """
 
     def update_user_identity_info(
         self, IdentityInfo: "UserIdentityInfoTypeDef", UserId: str, InstanceId: str
     ) -> None:
         """
-        [Client.update_user_identity_info documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.update_user_identity_info)
+        [Client.update_user_identity_info documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.update_user_identity_info)
         """
 
     def update_user_phone_config(
         self, PhoneConfig: "UserPhoneConfigTypeDef", UserId: str, InstanceId: str
     ) -> None:
         """
-        [Client.update_user_phone_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.update_user_phone_config)
+        [Client.update_user_phone_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.update_user_phone_config)
         """
 
     def update_user_routing_profile(
         self, RoutingProfileId: str, UserId: str, InstanceId: str
     ) -> None:
         """
-        [Client.update_user_routing_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.update_user_routing_profile)
+        [Client.update_user_routing_profile documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.update_user_routing_profile)
         """
 
     def update_user_security_profiles(
         self, SecurityProfileIds: List[str], UserId: str, InstanceId: str
     ) -> None:
         """
-        [Client.update_user_security_profiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Client.update_user_security_profiles)
+        [Client.update_user_security_profiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Client.update_user_security_profiles)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_metric_data"]) -> GetMetricDataPaginator:
         """
-        [Paginator.GetMetricData documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Paginator.GetMetricData)
+        [Paginator.GetMetricData documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Paginator.GetMetricData)
         """
 
     @overload
@@ -641,7 +648,7 @@ class ConnectClient:
         self, operation_name: Literal["list_contact_flows"]
     ) -> ListContactFlowsPaginator:
         """
-        [Paginator.ListContactFlows documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Paginator.ListContactFlows)
+        [Paginator.ListContactFlows documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Paginator.ListContactFlows)
         """
 
     @overload
@@ -649,7 +656,7 @@ class ConnectClient:
         self, operation_name: Literal["list_hours_of_operations"]
     ) -> ListHoursOfOperationsPaginator:
         """
-        [Paginator.ListHoursOfOperations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Paginator.ListHoursOfOperations)
+        [Paginator.ListHoursOfOperations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Paginator.ListHoursOfOperations)
         """
 
     @overload
@@ -657,13 +664,13 @@ class ConnectClient:
         self, operation_name: Literal["list_phone_numbers"]
     ) -> ListPhoneNumbersPaginator:
         """
-        [Paginator.ListPhoneNumbers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Paginator.ListPhoneNumbers)
+        [Paginator.ListPhoneNumbers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Paginator.ListPhoneNumbers)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_queues"]) -> ListQueuesPaginator:
         """
-        [Paginator.ListQueues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Paginator.ListQueues)
+        [Paginator.ListQueues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Paginator.ListQueues)
         """
 
     @overload
@@ -671,7 +678,7 @@ class ConnectClient:
         self, operation_name: Literal["list_routing_profiles"]
     ) -> ListRoutingProfilesPaginator:
         """
-        [Paginator.ListRoutingProfiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Paginator.ListRoutingProfiles)
+        [Paginator.ListRoutingProfiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Paginator.ListRoutingProfiles)
         """
 
     @overload
@@ -679,7 +686,7 @@ class ConnectClient:
         self, operation_name: Literal["list_security_profiles"]
     ) -> ListSecurityProfilesPaginator:
         """
-        [Paginator.ListSecurityProfiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Paginator.ListSecurityProfiles)
+        [Paginator.ListSecurityProfiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Paginator.ListSecurityProfiles)
         """
 
     @overload
@@ -687,11 +694,11 @@ class ConnectClient:
         self, operation_name: Literal["list_user_hierarchy_groups"]
     ) -> ListUserHierarchyGroupsPaginator:
         """
-        [Paginator.ListUserHierarchyGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Paginator.ListUserHierarchyGroups)
+        [Paginator.ListUserHierarchyGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Paginator.ListUserHierarchyGroups)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_users"]) -> ListUsersPaginator:
         """
-        [Paginator.ListUsers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/connect.html#Connect.Paginator.ListUsers)
+        [Paginator.ListUsers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.62/reference/services/connect.html#Connect.Paginator.ListUsers)
         """
